#!/bin/sh
# ----------------------------------------------------------------------------
# /tmp/install.sh - minidlna installation
#
# Creation   : 2010-01-02 jk
# Last update: $Id: install.sh 15 2010-01-02 18:50:36Z jk $
#
# Copyright (c) 2010 the eisfair team, <team(at)eisfair(dot)org>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# ----------------------------------------------------------------------------

# include eislib
. /var/install/include/eislib

# set package name
packageName=minidlna

package_menu_item='MiniDLNA'
package_pos=73

# define package positions of start/stop-scripts
package_start='S'${package_pos}${packageName}
package_kill='K'`/usr/bin/expr 100 - $package_pos`${packageName}

# define config and default file
# configfile=/etc/config.d/${packageName}
# defaultfile=/etc/default.d/${packageName}

#------------------------------------------------------------------------------
# show infos
#------------------------------------------------------------------------------
mecho -info "Starting installation of $packageName ..."

# ----------------------------------------------------------------------------
# Setup step 1
# ----------------------------------------------------------------------------

# Setup system specific values
if [ -z "${EISFAIR_SYSTEM}" ]
then
    # get eisfair system-type
    . /var/install/include/check-eisfair-version
fi

#-------------------------------------------------------------------------------
# creating symbolic links for start/stop
#-------------------------------------------------------------------------------
mecho -n "creating symbolic links for $packageName ..."

case ${EISFAIR_SYSTEM} in
    eisfair-2)
        # eisfair-2

        rm -f /etc/rc[0126S].d/[KS]??${packageName}
        ln -sf /etc/init.d/${packageName} /etc/rc0.d/${package_kill}
        ln -sf /etc/init.d/${packageName} /etc/rc1.d/${package_kill}
        ln -sf /etc/init.d/${packageName} /etc/rc6.d/${package_kill}
        ln -sf /etc/init.d/${packageName} /etc/rc2.d/${package_start}
        ;;
    *)
        # default to eisfair-1

        rm -f /etc/rc2.d/[KS]??${packageName}
        ln -sf /etc/init.d/${packageName} /etc/rc2.d/${package_kill}
        ln -sf /etc/init.d/${packageName} /etc/rc2.d/${package_start}
        ;;
esac

mecho "   done"


# ----------------------------------------------------------------------------
# Add menu
# ----------------------------------------------------------------------------
mecho -n "Adding menu entry '$package_menu_item' for '$packageName' ..."
/var/install/bin/add-menu setup.services.menu setup.services.${packageName}.menu "${package_menu_item}"
mecho "   done"

# ----------------------------------------------------------------------------
# Create default config
# ----------------------------------------------------------------------------

/var/install/config.d/${packageName}-update.sh

#------------------------------------------------------------------------------
# read configuration
#------------------------------------------------------------------------------
. /etc/config.d/${packageName}

# ----------------------------------------------------------------------------
# Start configuration editor if necessary
# ----------------------------------------------------------------------------

if [ "${START_MINIDLNA}" == "no" ]
then
    /var/install/bin/edit -apply ${packageName} "Edit ${packageName} configuration"
else
    /var/install/config.d/${packageName}.sh --quiet
fi


exit 0
# ----------------------------------------------------------------------------
# End
# ----------------------------------------------------------------------------

