#!/bin/sh
# ----------------------------------------------------------------------------
# /var/install/config.d/minidlna.sh - MINIDLNA configuration
#
# Creation   : 2010-01-02 jk
# Last update: $Id: minidlna.sh 15 2010-01-02 18:50:36Z jk $
#
# Copyright (c) 2010 the eisfair team, <team(at)eisfair(dot)org>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# ----------------------------------------------------------------------------

#exec 2> `pwd`/minidlna-trace$$.log
#set -x

# ----------------------------------------------------------------------------
# Config Dateien
# ----------------------------------------------------------------------------

# include eislib
. /var/install/include/eislib

# include config
. /etc/config.d/minidlna

# set package name
packageName=minidlna

# ----------------------------------------------------------------------------
# Functions
# ----------------------------------------------------------------------------

#-------------------------------------------------------------------------------
# create directories
#-------------------------------------------------------------------------------
createDirectories ()
{
    mecho -info "Creating ${packageName} directories ..."
    
    if [ ! -d "/var/lib/${packageName}" ]
    then
        mkdir /var/lib/${packageName}
    fi
}

#-------------------------------------------------------------------------------
# create start file
#-------------------------------------------------------------------------------
createStartFile ()
{
    mecho -info "creating minidlna's start file"

    # Preset VLC_OPTS
    MINIDLNA_OPTS=

    # Write verbose level
#    if [ "${MINIDLNA_DO_DEBUG}" -ne "0" ]; then
#        MINIDLNA_OPTS="${MINIDLNA_OPTS} -d"
#    fi
    
    # Write information to start-file
    STARTFILE="/var/lib/${packageName}/${packageName}-start"
    (
	    echo "#! /bin/sh"
        echo "#------------------------------------------------------------------"
        echo "# ${STARTFILE} file generated by ${PACKAGE_NAME} version: ${VERSION}"
        echo "#"
        echo "# Do not edit this file, edit ${CONFIG_FILE}"
        echo "# Creation Date: ${EISDATE} Time: ${EISTIME}"
        echo "#------------------------------------------------------------------"
        echo ""
        echo "/usr/sbin/${packageName} ${MINIDLNA_OPTS} -f /var/lib/${packageName}/${packageName}.conf"
        echo ""
    ) > ${STARTFILE}
    chmod 0764 ${STARTFILE}
}


#-------------------------------------------------------------------------------
# create configuration file
#-------------------------------------------------------------------------------
createConfigurationFile ()
{
    mecho -info "creating ${packageName} configuration file"
    
    # Write information to configuration file
    CONFIGFILE="/var/lib/${packageName}/${packageName}.conf"
    (
        echo "#! /bin/sh"
        echo "#-----------------------------------------------------------------------------"
        echo "# ${STARTFILE} file generated by $0 "
        echo "# $CONFIGFILE    "
        echo "# Do not change this file; instead change /etc/config.d/${packageName}"
        echo "# Creation date: `date` "
        echo "#-----------------------------------------------------------------------------"
        echo "#"
        echo "port=$MINIDLNA_PORT"
        echo "network_interface=$MINIDLNA_NW_INTERFACE"

        # check amount of media directories
        if [ $MINIDLNA_MEDIA_N -eq 0 ]
            then
                    imax=1
            else
                    imax=$MINIDLNA_MEDIA_N
            fi

        # write each media directory into config file
            idx=1
            while [ "$idx" -le $imax ]
            do
                eval pDir='$MINIDLNA_MEDIA_'$idx'_DIR'
                eval pContent='$MINIDLNA_MEDIA_'$idx'_CONTENT'

                case ${pContent}
                in
                    "Audio")
                        pCon="A,"
                    ;;
                    "Video")
                        pCon="V,"
                    ;;
                    "Photo")
                        pCon="P,"
                    ;;
                    *)
                        pCon=""
                    ;;
                esac            
            echo "media_dir=$pCon$pDir"
            idx=`/usr/bin/expr $idx + 1`
            done

        echo "friendly_name=$MINIDLNA_NAME"
        echo "db_dir=/var/lib/${packageName}"
        echo "album_art_names=$MINIDLNA_ALBUM_NAMES"
        echo "inotify=$MINIDLNA_INOTIFY"
        echo "enable_tivo=$MINIDLNA_ENABLE_TIVO"
        echo "strict_dlna=$MINIDLNA_STRICT_DLNA"
        echo "presentation_url=$MINIDLNA_WEB_URL"
        echo "notify_interval=$MINIDLNA_NTFY_INTERVAL"
        echo "serial=$MINIDLNA_SERIAL"
        echo "model_number=$MINIDLNA_MODEL_NUMBER"
    ) > ${CONFIGFILE}
    chmod 0644 ${CONFIGFILE}
}


# ----------------------------------------------------------------------------
# Main
# ----------------------------------------------------------------------------
createDirectories
createConfigurationFile 
createStartFile

mecho -info "${packageName}.sh done"
exit 0
# ----------------------------------------------------------------------------
# End
# ----------------------------------------------------------------------------

